@@ -23,15 +23,23 @@ var incognito = require("incognito");
 
 require.scopes.heuristicblocking = (function() {
 
+
+
 /*********************** heuristicblocking scope **/
-
 // make heuristic obj with utils and storage properties and put the things on it
-var tabOrigins = { }; // TODO roll into tabData?
-
 function HeuristicBlocker(pbStorage) {
   this.storage = pbStorage;
 }
 
+// TODO roll into tabData? -- 6/10/2019 not for now, since tabData is populated
+// by the synchronous listeners in webrequests.js and tabOrigins is used by the
+// async listeners here; there's no way to enforce ordering of requests among
+// those two. Also, tabData is cleaned up every time a tab is closed, so
+// dangling requests that don't trigger listeners until after the tab closes are
+// impossible to attribute to a tab.
+var tabOrigins = { };
+var tabURLs = { };
+
 HeuristicBlocker.prototype = {
   /**
    * Adds Cookie blocking for all more specific domains than the blocked origin
@@ -93,9 +101,10 @@ HeuristicBlocker.prototype = {
    * Use updateTrackerPrevalence for non-webRequest initiated bookkeeping.
    *
    * @param details are those from onBeforeSendHeaders
+   * @param {Boolean} check_for_cookie_share whether to check for cookie sharing
    * @returns {*}
    */
-  heuristicBlockingAccounting: function (details) {
+  heuristicBlockingAccounting: function (details, check_for_cookie_share) {
     // ignore requests that are outside a tabbed window
     if (details.tabId < 0 || !incognito.learningEnabled(details.tabId)) {
       return {};
@@ -104,33 +113,144 @@ HeuristicBlocker.prototype = {
     let fqdn = (new URI(details.url)).host,
       origin = window.getBaseDomain(fqdn);
 
-    // if this is a main window request
+    // if this is a main window request, update tab data and quit
     if (details.type == "main_frame") {
-      // save the origin associated with the tab
-      log("Origin: " + origin + "\tURL: " + details.url);
       tabOrigins[details.tabId] = origin;
+      tabURLs[details.tabId] = details.url;
       return {};
     }
 
-    let tabOrigin = tabOrigins[details.tabId];
+    let tab_origin = tabOrigins[details.tabId],
+      self = this;
 
     // ignore first-party requests
-    if (!tabOrigin || origin == tabOrigin) {
+    if (!tab_origin || origin == tab_origin) {
+      return {};
+    }
+
+    // short-circuit if we already observed this origin tracking on this site
+    let firstParties = self.storage.getBadgerStorageObject('snitch_map').getItem(origin);
+    if (firstParties && firstParties.indexOf(tab_origin) > -1) {
       return {};
     }
 
     // abort if we already made a decision for this FQDN
-    let action = this.storage.getAction(fqdn);
+    let action = self.storage.getAction(fqdn);
     if (action != constants.NO_TRACKING && action != constants.ALLOW) {
       return {};
     }
 
-    // ignore if there are no tracking cookies
-    if (!hasCookieTracking(details, origin)) {
+    // check if there are tracking cookies
+    if (hasCookieTracking(details, origin)) {
+      self._recordPrevalence(fqdn, origin, tab_origin);
       return {};
     }
 
-    this._recordPrevalence(fqdn, origin, tabOrigin);
+    // check for cookie sharing iff this is an image and the request URL has parameters
+    if (check_for_cookie_share && details.type == 'image' && details.url.indexOf('?') > -1) {
+      // get all cookies for the top-level frame and pass those to the
+      // cookie-share accounting function
+      let tab_url = tabURLs[details.tabId];
+      chrome.cookies.getAll({
+        url: tab_url
+      }, function(cookies) {
+        if (cookies.length >= 1) {
+          self.pixelCookieShareAccounting(tab_url, tab_origin, details.url, fqdn, origin, cookies);
+        }
+      });
+    }
+  },
+
+  /**
+   * Checks for cookie sharing: requests to third-party domains that include
+   * high entropy data from first-party cookies (associated with the top-level
+   * frame). Only catches plain-text verbatim sharing (b64 encoding + the like
+   * defeat it). Assumes any long string that doesn't contain URL fragments or
+   * stopwords is an identifier.  Doesn't catch cookie syncing (3rd party -> 3rd
+   * party), but most of those tracking cookies should be blocked anyway.
+   *
+   * @param details are those from onBeforeSendHeaders
+   * @param cookies are the result of chrome.cookies.getAll()
+   * @returns {*}
+   */
+  pixelCookieShareAccounting: function (tab_url, tab_origin, request_url, request_fqdn, request_origin, cookies) {
+    let params = (new URL(request_url)).searchParams,
+      TRACKER_ENTROPY_THRESHOLD = 33,
+      MIN_STR_LEN = 8;
+
+    for (let p of params) {
+      let key = p[0],
+        value = p[1];
+
+      // the argument must be sufficiently long
+      if (!value || value.length < MIN_STR_LEN) {
+        continue;
+      }
+
+      // check if this argument is derived from a high-entropy first-party cookie
+      for (let cookie of cookies) {
+        // the cookie value must be sufficiently long
+        if (!cookie.value || cookie.value.length < MIN_STR_LEN) {
+          continue;
+        }
+
+        // find the longest common substring between this arg and the cookies
+        // associated with the document
+        let substrings = utils.findCommonSubstrings(cookie.value, value) || [];
+        for (let s of substrings) {
+          // ignore the substring if it's part of the first-party URL. sometimes
+          // content servers take the url of the page they're hosting content
+          // for as an argument. e.g.
+          // https://example-cdn.com/content?u=http://example.com/index.html
+          if (tab_url.indexOf(s) != -1) {
+            continue;
+          }
+
+          // elements of the user agent string are also commonly included in
+          // both cookies and arguments; e.g. "Mozilla/5.0" might be in both.
+          // This is not a special tracking risk since third parties can see
+          // this info anyway.
+          if (navigator.userAgent.indexOf(s) != -1) {
+            continue;
+          }
+
+          // Sometimes the entire url and then some is included in the
+          // substring -- the common string might be "https://example.com/:true"
+          // In that case, we only care about the information around the URL.
+          if (s.indexOf(tab_url) != -1) {
+            s = s.replace(tab_url, "");
+          }
+
+          // During testing we found lots of common values like "homepage",
+          // "referrer", etc. were being flagged as high entropy. This searches
+          // for a few of those and removes them before we go further.
+          let lower = s.toLowerCase();
+          lowEntropyQueryValues.forEach(function (qv) {
+            let start = lower.indexOf(qv);
+            if (start != -1) {
+              s = s.replace(s.substring(start, start + qv.length), "");
+            }
+          });
+
+          // at this point, since we might have removed things, make sure the
+          // string is still long enough to bother with
+          if (s.length < MIN_STR_LEN) {
+            continue;
+          }
+
+          // compute the entropy of this common substring. if it's greater than
+          // our threshold, record the tracking action and exit the function.
+          let entropy = utils.estimateMaxEntropy(s);
+          if (entropy > TRACKER_ENTROPY_THRESHOLD) {
+            log("Found high-entropy cookie share from", tab_origin, "to", request_fqdn,
+              ":", entropy, "bits\n  cookie:", cookie.name, '=', cookie.value,
+              "\n  arg:", key, "=", value, "\n  substring:", s);
+            this._recordPrevalence(request_fqdn, request_origin, tab_origin);
+            return;
+          }
+        }
+      }
+    }
   },
 
   /**
@@ -431,6 +551,51 @@ var lowEntropyCookieValues = {
   "zu":8
 };
 
+const lowEntropyQueryValues = [
+  "https",
+  "http",
+  "://",
+  "%3A%2F%2F",
+  "www",
+  "url",
+  "undefined",
+  "impression",
+  "session",
+  "homepage",
+  "client",
+  "version",
+  "business",
+  "title",
+  "get",
+  "site",
+  "name",
+  "category",
+  "account_id",
+  "smartadserver",
+  "front",
+  "page",
+  "view",
+  "first",
+  "visit",
+  "platform",
+  "language",
+  "automatic",
+  "disabled",
+  "landing",
+  "entertainment",
+  "amazon",
+  "official",
+  "webvisor",
+  "anonymous",
+  "across",
+  "narrative",
+  "\":null",
+  "\":false",
+  "\":\"",
+  "\",\"",
+  "\",\"",
+];
+
 /**
  * Extract cookies from onBeforeSendHeaders
  *
@@ -519,7 +684,7 @@ function startListeners() {
     extraInfoSpec.push('extraHeaders');
   }
   chrome.webRequest.onBeforeSendHeaders.addListener(function(details) {
-    return badger.heuristicBlocking.heuristicBlockingAccounting(details);
+    return badger.heuristicBlocking.heuristicBlockingAccounting(details, true);
   }, {urls: ["<all_urls>"]}, extraInfoSpec);
 
   /**
@@ -538,7 +703,7 @@ function startListeners() {
       }
     }
     if (hasSetCookie) {
-      return badger.heuristicBlocking.heuristicBlockingAccounting(details);
+      return badger.heuristicBlocking.heuristicBlockingAccounting(details, false);
     }
   },
   {urls: ["<all_urls>"]}, extraInfoSpec);
