@@ -44,6 +44,114 @@ var multiDomainFirstPartiesArray = [
     "myportfolio.com",
     "typekit.com",
   ],
+  [
+    "alibaba.com",
+
+    "1688.com",
+    "95095.com",
+    "9game.cn",
+    "alibabagroup.com",
+    "alibaba-inc.com",
+    "alicdn.com",
+    "alicdn.net",
+    "aliexpress.com",
+    "aligames.com",
+    "alihealth.cn",
+    "alihive.com",
+    "aliimg.com",
+    "alimama.com",
+    "alitrip.com",
+    "alitrip.hk",
+    "aliyun.com",
+    "cainiao.com",
+    "cainiao.com.cn",
+    "cibntv.net",
+    "cnzz.com",
+    "dayu.com",
+    "dingtalkapps.com",
+    "dingtalk.com",
+    "dongting.com",
+    "ele.me",
+    "elenet.me",
+    "etao.com",
+    "feizhu.cn",
+    "feizhu.com",
+    "fliggy.com",
+    "fliggy.hk",
+    "i52hz.com",
+    "jiaoyimao.com",
+    "jingguan.ai",
+    "jiyoujia.com",
+    "juhuasuan.com",
+    "kumiao.com",
+    "laifeng.com",
+    "liangxinyao.com",
+    "mappcloud.com",
+    "mei.com",
+    "mmstat.com",
+    "mobmore.com",
+    "paike.com",
+    "puata.info",
+    "soku.com",
+    "tanx.com",
+    "taobao.com",
+    "taopiaopiao.com",
+    "tbcdn.cn",
+    "tmail.com",
+    "tmall.com",
+    "tmall.hk",
+    "ttpod.com",
+    "tudou.com",
+    "uc.cn",
+    "ucweb.com",
+    "um0.cn",
+    "umengcloud.com",
+    "umeng.co",
+    "umeng.com",
+    "umindex.com",
+    "umsns.com",
+    "umtrack.com",
+    "wasu.tv",
+    "whalecloud.com",
+    "www.net.cn",
+    "xiami.com",
+    "ykimg.com",
+    "youku.com",
+    "youkutv.com",
+    "yousuode.cn",
+
+
+    "alipay.com",
+
+    "aliloan.com",
+    "alipay-cloud.com",
+    "alipay.cn",
+    "alipay.com",
+    "alipay-eco.com",
+    "alipay.hk",
+    "alipayplus.com",
+    "ant-biz.com",
+    "ant-financial.com",
+    "antfin.com",
+    "antfin-inc.com",
+    "antfortune.com",
+    "antgroup.com",
+    "ant-open.com",
+    "antsdaq.com",
+    "ebuckler.com",
+    "fund123.cn",
+    "huijucai.com",
+    "koubei.com",
+    "mayiyunbao.com",
+    "mybank.cn",
+    "sinopayment.com.cn",
+    "ssdata.com",
+    "xin.xin",
+    "yidun.com",
+    "zamcs.com",
+    "zhisheng.com",
+    "zmxy.com.cn",
+  ],
   ["allstate.com", "myallstate.com"],
   ["altra.org", "altraonline.org"],
   [
@@ -134,6 +242,27 @@ var multiDomainFirstPartiesArray = [
     "ancestrycdn.com",
   ],
   ["androidcentral.com", "mobilenations.com"],
+  [
+    "apa.at",
+    "apa-it.at",
+    "apa-defacto.at",
+    "ots.at",
+
+    "orf.at",
+    "oe24.at",
+    "wienerzeitung.at",
+    "kleinezeitung.at",
+    "vn.at",
+    "kurier.at",
+    "nachrichten.at",
+    "derstandard.at",
+    "sn.at",
+    "volksblatt.at",
+    "neue.at",
+
+    "tt.com",
+    "diepresse.com",
+  ],
   ["apple.com", "icloud.com"],
   ["applefcu.org", "applefcuonline.org"],
   ["archive.org", "openlibrary.org"],
@@ -181,6 +310,7 @@ var multiDomainFirstPartiesArray = [
   ["avito.ru", "avito.st"],
   ["avon.com", "youravon.com"],
   ["baidu.com", "bdimg.com", "bdstatic.com"],
+  ["balsamiq.com", "balsamiq.cloud"],
   ["bancomer.com", "bancomer.com.mx", "bbvanet.com.mx"],
   ["bankofamerica.com", "bofa.com", "mbna.com", "usecfo.com"],
   ["bank-yahav.co.il", "bankhapoalim.co.il"],
@@ -200,6 +330,8 @@ var multiDomainFirstPartiesArray = [
     "statuspage.io",
     "stride.com",
     "trello.com",
+
+    "atl-paas.net",
   ],
   ["blizzard.com", "battle.net", "worldofwarcraft.com"],
   ["bloomberg.com", "bbthat.com", "bwbx.io"],
@@ -247,16 +379,48 @@ var multiDomainFirstPartiesArray = [
     "upload.com",
     "zdnet.com",
   ],
+  ["cb2.com", "crateandbarrel.com"],
   ["century21.com", "21online.com"],
   ["chart.io", "chartio.com"],
   ["concur.com", "concursolutions.com"],
   ["cox.com", "cox.net"],
   ["cricketwireless.com", "aiowireless.com"],
+  ["ctrip.com", "c-ctrip.com", "trip.com"],
   ["dcu.org", "dcu-online.org"],
   ["diapers.com", "soap.com", "wag.com", "yoyo.com", "beautybar.com", "casa.com", "afterschool.com", "vine.com", "bookworm.com", "look.com", "vinemarket.com"],
   ["dictionary.com", "thesaurus.com", "sfdict.com"],
   ["discountbank.co.il", "telebank.co.il"],
   ["discover.com", "discovercard.com"],
+  [
+    "dpgmediagroup.com",
+
+    "persgroep.net",
+    "persgroep.cloud",
+
+    "7sur7.be",
+    "ad.nl",
+    "bd.nl",
+    "beursrally.be",
+    "beurswijzer.com",
+    "bndestem.nl",
+    "demorgen.be",
+    "destentor.nl",
+    "dpgmedia.be",
+    "ed.nl",
+    "gelderlander.nl",
+    "hln.be",
+    "parool.nl",
+    "persgroepinternational.be",
+    "persgroepinternational.com",
+    "persgroep.nl",
+    "pzc.nl",
+    "tijd.be",
+    "topics.be",
+    "topics.nl",
+    "trouw.nl",
+    "tubantia.nl",
+    "volkskrant.nl",
+  ],
   ["dropbox.com", "dropboxstatic.com", "dropboxusercontent.com", "getdropbox.com"],
   ["d.rip", "kickstarter.com"],
   ["ea.com", "origin.com", "play4free.com", "tiberiumalliance.com"],
@@ -287,12 +451,26 @@ var multiDomainFirstPartiesArray = [
     "ebayrtm.com",
     "ebaystatic.com",
   ],
+  ["elsevier.com", "sciencedirect.com", "sciencedirectassets.com"],
   [
     "enterprise.com",
 
     "alamo.ca",
     "alamo.com",
 
+    "autoshare.com",
+    "autoshare.biz",
+    "autoshare.ca",
+    "autoshare.net",
+    "autoshare.org",
+
+    "cars.info",
+    "carsharing.ca",
+    "carsharingtoronto.com",
+    "citer.fr",
+
+    "ehi.com",
+
     "enterprise.ca",
     "enterprise.ch",
     "enterprise.com.jm",
@@ -313,6 +491,7 @@ var multiDomainFirstPartiesArray = [
     "enterprise.se",
 
     "enterprisecarclub.co.uk",
+    "enterprisecarclub.ie",
 
     "enterprisecarshare.ca",
     "enterprisecarshare.com",
@@ -340,6 +519,9 @@ var multiDomainFirstPartiesArray = [
     "nationalcar.fr",
     "nationalcar.ie",
     "nationalcar.it",
+    "nationalcar.mobi",
+
+    "onewaygo.de",
   ],
   [
     "expedia.com",
@@ -882,8 +1064,29 @@ var multiDomainFirstPartiesArray = [
     "stghouzz.com",
     "thathomesite.com",
   ],
+  [
+    "huffpost.com",
+
+    "huffingtonpost.ca",
+    "huffingtonpost.com",
+    "huffingtonpost.com.au",
+    "huffingtonpost.com.mx",
+    "huffingtonpost.co.uk",
+    "huffingtonpost.co.za",
+    "huffingtonpost.de",
+    "huffingtonpost.es",
+    "huffingtonpost.fr",
+    "huffingtonpost.gr",
+    "huffingtonpost.in",
+    "huffingtonpost.it",
+    "huffingtonpost.jp",
+    "huffingtonpost.kr",
+    "huffpostarabi.com",
+    "huffpostbrasil.com",
+    "huffpostmaghreb.com",
+  ],
   ["hvfcu.org", "hvfcuonline.org"],
-  ["ign.fr", "geoportail.gouv.fr"],
+  ["ign.fr", "geoportail.gouv.fr", "geoportail-urbanisme.gouv.fr", "cartoradio.fr", "ignrando.fr"],
   ["lnk.to", "tix.to", "tck.to", "ticket.to", "linkfire.com", "assetlab.io", "linkfire.co", "lnkfi.re"],
   ["logmein.com", "logme.in"],
   ["macys.com", "macysassets.com"],
@@ -896,6 +1099,7 @@ var multiDomainFirstPartiesArray = [
   [
     "microsoft.com",
 
+    "1drv.ms",
     "aspnetcdn.com",
     "azure.com",
     "azureedge.net",
@@ -915,14 +1119,20 @@ var multiDomainFirstPartiesArray = [
     "office365.com",
     "office.com",
     "office.net",
+    "onedrive.com",
     "onenote.com",
     "onestore.ms",
     "passport.net",
     "sharepoint.com",
+    "sharepoint-df.com",
+    "sharept.ms",
     "skypeassets.com",
     "skype.com",
     "s-microsoft.com",
+    "svc.ms",
     "visualstudio.com",
+    "vsallin.net",
+    "vsassets.io",
     "windowsazure.com",
     "windows.com",
     "xbox.com",
@@ -1139,7 +1349,7 @@ var multiDomainFirstPartiesArray = [
     "zappelin.nl",
     "zapp.nl",
   ],
-  ["nymag.com", "vulture.com", "grubstreet.com"],
+  ["nymag.com", "vulture.com", "grubstreet.com", "thecut.com"],
   [
     "nypublicradio.org",
 
@@ -1152,6 +1362,11 @@ var multiDomainFirstPartiesArray = [
     "wnyc.org",
   ],
   ["nytimes.com", "newyorktimes.com", "nyt.com"],
+  [
+    "nyu.edu",
+
+    "nyupress.org",
+  ],
   [
     "nvidia.com",
 
@@ -1371,6 +1586,7 @@ var multiDomainFirstPartiesArray = [
     "reastatic.net",
   ],
   ["reddit.com", "redditmedia.com", "redditstatic.com", "redd.it", "redditenhancementsuite.com", "reddituploads.com", "imgur.com"],
+  ["redhat.com", "openshift.com", "openshift.org", "okd.io"],
   [
     "reuters.com",
     "reuters.tv",
@@ -1425,6 +1641,18 @@ var multiDomainFirstPartiesArray = [
   ["skysports.com", "skybet.com", "skyvegas.com"],
   ["slashdot.org", "sourceforge.net", "fsdn.com"],
   ["slickdeals.net", "slickdealscdn.com"],
+  [
+    "smh.com.au",
+
+    "afr.com",
+    "brisbanetimes.com.au",
+    "canberratimes.com.au",
+    "fairfaxmedia.com.au",
+    "theage.com.au",
+    "watoday.com.au",
+
+    "ffx.io",
+  ],
   ["snapfish.com", "snapfish.ca"],
   ["sony.com", "sonyrewards.com"],
   ["soundcu.com", "netteller.com"],
@@ -1470,8 +1698,6 @@ var multiDomainFirstPartiesArray = [
   ["sprint.com", "sprintpcs.com", "nextel.com"],
   ["squareup.com", "cash.app", "mkt.com", "squarecdn.com"],
   ["steampowered.com", "steamstatic.com", "steamcommunity.com"],
-  ["taobao.com", "alicdn.net", "tmail.com", "tbcdn.cn", "alibaba.com",
-    "aliexpress.com", "tmall.com", "alimama.com", "1688.com", "aliyun.com", "www.net.cn"],
   ["techdata.com", "techdata.ch"],
   ["telegram.org", "telegram.me", "t.me"],
   ["telekom.com", "t-online.de"],
@@ -1651,7 +1877,6 @@ var multiDomainFirstPartiesArray = [
     "vinted.pl",
   ],
   ["vk.com", "vk.me", "vkontakte.ru"],
-  ["volkskrant.nl", "persgroep.net", "persgroep.nl", "parool.nl"],
   ["volvooceanrace.com", "virtualregatta.com"],
   ["vonage.com", "vonagebusiness.com"],
   ["walmart.com", "wal.co", "walmartimages.com", "walmart.ca"],
@@ -1672,7 +1897,8 @@ var multiDomainFirstPartiesArray = [
   ["wetter.com", "tiempo.es", "wettercomassets.com"],
   ["wikipedia.org", "wikimedia.org", "wikimediafoundation.org", "wiktionary.org",
     "wikiquote.org", "wikibooks.org", "wikisource.org", "wikinews.org",
-    "wikiversity.org", "mediawiki.org", "wikidata.org", "wikivoyage.org"],
+    "wikiversity.org", "mediawiki.org", "wikidata.org", "wikivoyage.org",
+    "wmfusercontent.org", "tools.wmflabs.org"],
   ["wix.com", "wixapps.net", "wixstatic.com", "parastorage.com"],
   ["wordpress.com", "wp.com"],
   [
@@ -1709,7 +1935,6 @@ var multiDomainFirstPartiesArray = [
   ["wsj.com", "wsj.net", "barrons.com", "dowjones.com", "marketwatch.com"],
   ["xda-developers.com", "xda-cdn.com"],
   ["xfinity.com", "comcast.net", "comcast.com"],
-  ["xiami.com", "alipay.com"],
   ["yahoo.com", "yahooapis.com", "yimg.com", "yahoo.co.jp", "overture.com", "flickr.com"],
   [
     "yandex.com",
@@ -1718,17 +1943,18 @@ var multiDomainFirstPartiesArray = [
     "beru.ru",
     "kinopoisk.ru",
     "mykp.ru",
+    "yadi.sk",
 
     "yandex.net",
-    "ya.ru",
     "yastatic.net",
 
     "yandex.az",
     "yandex.by",
     "yandex.co.il",
-    "yandex.com",
+    "yandex.com.am",
     "yandex.com.ge",
     "yandex.com.tr",
+    "yandex.com.ua",
     "yandex.ee",
     "yandex.fr",
     "yandex.kg",
@@ -1741,6 +1967,7 @@ var multiDomainFirstPartiesArray = [
     "yandex.tm",
     "yandex.ua",
     "yandex.uz",
+    "ya.ru",
   ],
   ["zendesk.com", "zopim.com"],
   ["zillow.com", "zillowstatic.com", "zillowcloud.com"],
