@@ -192,7 +192,7 @@ function onBeforeSendHeaders(details) {
   if (requestAction == constants.ALLOW &&
       badger.storage.getTrackingCount(requestDomain) == constants.TRACKING_THRESHOLD - 1) {
 
-    badger.heuristicBlocking.heuristicBlockingAccounting(details);
+    badger.heuristicBlocking.heuristicBlockingAccounting(details, false);
     requestAction = checkAction(tab_id, requestDomain, frame_id);
 
     if (requestAction) {
@@ -745,9 +745,11 @@ function dispatcher(request, sender, sendResponse) {
       noTabData: !has_tab_data,
       origins: has_tab_data && badger.tabData[tab_id].origins,
       seenComic: badger.getSettings().getItem("seenComic"),
+      showNonTrackingDomains: badger.getSettings().getItem("showNonTrackingDomains"),
       tabHost: tab_host,
       tabId: tab_id,
-      tabUrl: tab_url
+      tabUrl: tab_url,
+      trackerCount: has_tab_data && badger.getTrackerCount(tab_id)
     });
 
   } else if (request.type == "getOptionsData") {
@@ -759,6 +761,7 @@ function dispatcher(request, sender, sendResponse) {
       isWidgetReplacementEnabled: badger.isWidgetReplacementEnabled(),
       origins: badger.storage.getTrackingDomains(),
       showCounter: badger.showCounter(),
+      showNonTrackingDomains: badger.getSettings().getItem("showNonTrackingDomains"),
       showTrackingDomains: badger.getSettings().getItem("showTrackingDomains"),
       webRTCAvailable: badger.webRTCAvailable,
     });
