@@ -40,16 +40,16 @@ function() {
     const DOMAIN = "example.com";
 
     assert.equal(
-      badger.getBlockedOriginCount(this.tabId), 0, "count starts at zero"
+      badger.getTrackerCount(this.tabId), 0, "count starts at zero"
     );
 
-    // set up domain blocking (used by getBlockedOriginCount)
+    // set up domain blocking (used by getTrackerCount)
     badger.storage.setupHeuristicAction(DOMAIN, constants.BLOCK);
 
     // log blocked domain
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.BLOCK);
     assert.equal(
-      badger.getBlockedOriginCount(this.tabId), 1, "count gets incremented"
+      badger.getTrackerCount(this.tabId), 1, "count gets incremented"
     );
     assert.ok(
       chrome.browserAction.setBadgeText.calledOnce,
@@ -64,11 +64,26 @@ function() {
   QUnit.test("logging unblocked domain", function (assert) {
     badger.logThirdPartyOriginOnTab(this.tabId, "example.com", constants.ALLOW);
     assert.equal(
-      badger.getBlockedOriginCount(this.tabId), 0, "count stays at zero"
+      badger.getTrackerCount(this.tabId), 1, "count gets incremented"
+    );
+    assert.ok(
+      chrome.browserAction.setBadgeText.calledOnce,
+      "updateBadge gets called when we see an unblocked domain"
+    );
+    assert.ok(chrome.browserAction.setBadgeText.calledWithExactly({
+      tabId: this.tabId,
+      text: "1"
+    }), "setBadgeText was called with expected args");
+  });
+
+  QUnit.test("logging DNT-compliant domain", function (assert) {
+    badger.logThirdPartyOriginOnTab(this.tabId, "example.com", constants.DNT);
+    assert.equal(
+      badger.getTrackerCount(this.tabId), 0, "count stays at zero"
     );
     assert.ok(
       chrome.browserAction.setBadgeText.notCalled,
-      "updateBadge does not get called when we see an unblocked domain"
+      "updateBadge does not get called when we see a DNT-compliant domain"
     );
   });
 
@@ -78,13 +93,13 @@ function() {
     // log unblocked domain
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.ALLOW);
 
-    // set up domain blocking (used by getBlockedOriginCount)
+    // set up domain blocking (used by getTrackerCount)
     badger.storage.setupHeuristicAction(DOMAIN, constants.BLOCK);
 
     // log the same domain, this time as blocked
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.BLOCK);
     assert.equal(
-      badger.getBlockedOriginCount(this.tabId), 1, "count gets incremented"
+      badger.getTrackerCount(this.tabId), 1, "count gets incremented"
     );
     assert.ok(
       chrome.browserAction.setBadgeText.calledOnce,
@@ -99,13 +114,13 @@ function() {
   QUnit.test("logging blocked domain twice", function (assert) {
     const DOMAIN = "example.com";
 
-    // set up domain blocking (used by getBlockedOriginCount)
+    // set up domain blocking (used by getTrackerCount)
     badger.storage.setupHeuristicAction(DOMAIN, constants.BLOCK);
 
     // log blocked domain
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.BLOCK);
     assert.equal(
-      badger.getBlockedOriginCount(this.tabId), 1, "count gets incremented"
+      badger.getTrackerCount(this.tabId), 1, "count gets incremented"
     );
     assert.ok(
       chrome.browserAction.setBadgeText.calledOnce,
@@ -119,7 +134,7 @@ function() {
     // log the same blocked domain again
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.BLOCK);
     assert.equal(
-      badger.getBlockedOriginCount(this.tabId),
+      badger.getTrackerCount(this.tabId),
       1,
       "count does not get incremented"
     );
@@ -136,13 +151,13 @@ function() {
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.ALLOW);
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.ALLOW);
 
-    // set up domain blocking (used by getBlockedOriginCount)
+    // set up domain blocking (used by getTrackerCount)
     badger.storage.setupHeuristicAction(DOMAIN, constants.BLOCK);
 
     // log blocked domain
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.BLOCK);
     assert.equal(
-      badger.getBlockedOriginCount(this.tabId), 1, "count gets incremented"
+      badger.getTrackerCount(this.tabId), 1, "count gets incremented"
     );
     assert.ok(
       chrome.browserAction.setBadgeText.calledOnce,
@@ -156,7 +171,7 @@ function() {
     // log the same blocked domain again
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.BLOCK);
     assert.equal(
-      badger.getBlockedOriginCount(this.tabId),
+      badger.getTrackerCount(this.tabId),
       1,
       "count does not get incremented"
     );
@@ -169,13 +184,13 @@ function() {
   QUnit.test("logging cookieblocked domain", function (assert) {
     const DOMAIN = "example.com";
 
-    // set up domain blocking (used by getBlockedOriginCount)
+    // set up domain blocking (used by getTrackerCount)
     badger.storage.setupHeuristicAction(DOMAIN, constants.COOKIEBLOCK);
 
     // log cookieblocked domain
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN, constants.COOKIEBLOCK);
     assert.equal(
-      badger.getBlockedOriginCount(this.tabId), 1, "count gets incremented"
+      badger.getTrackerCount(this.tabId), 1, "count gets incremented"
     );
     assert.ok(
       chrome.browserAction.setBadgeText.calledOnce,
@@ -191,14 +206,14 @@ function() {
     const DOMAIN1 = "example.com",
       DOMAIN2 = "example.net";
 
-    // set up domain blocking (used by getBlockedOriginCount)
+    // set up domain blocking (used by getTrackerCount)
     badger.storage.setupHeuristicAction(DOMAIN1, constants.BLOCK);
     badger.storage.setupHeuristicAction(DOMAIN2, constants.COOKIEBLOCK);
 
     // log blocked domain
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN1, constants.BLOCK);
     assert.equal(
-      badger.getBlockedOriginCount(this.tabId), 1, "count gets incremented"
+      badger.getTrackerCount(this.tabId), 1, "count gets incremented"
     );
     assert.ok(
       chrome.browserAction.setBadgeText.calledOnce,
@@ -212,7 +227,7 @@ function() {
     // log cookieblocked domain
     badger.logThirdPartyOriginOnTab(this.tabId, DOMAIN2, constants.COOKIEBLOCK);
     assert.equal(
-      badger.getBlockedOriginCount(this.tabId), 2, "count gets incremented again"
+      badger.getTrackerCount(this.tabId), 2, "count gets incremented again"
     );
     assert.ok(
       chrome.browserAction.setBadgeText.calledTwice,
